@@ -14,7 +14,9 @@ def delete_user_level_runner_command(
     """Delete a user-level runner for the authenticated user.
 
     Args:
+        ctx: The Typer context.
         runner_id: The ID of the runner to delete.
+
     """
     from typing import Any  # noqa: PLC0415
 
@@ -26,11 +28,11 @@ def delete_user_level_runner_command(
     timeout: int = ctx.obj.get("timeout")
 
     def api_call() -> dict[str, Any] | None:
-        """
-        API call to delete a user-level runner.
+        """Delete a user-level runner.
 
         Returns:
             A dictionary containing the result of the deletion.
+
         """
         with gitea.client.gitea.Gitea(token=token, base_url=base_url) as client:
             return client.user.delete_user_level_runner(runner_id=runner_id, timeout=timeout)
