@@ -18,11 +18,12 @@ class Resource:
 
         Args:
             client: An instance of the Gitea client.
+
         """
         self.client = client
 
     def _get(self, endpoint: str, **kwargs: Any) -> Response:
-        """Helper method to perform a GET request.
+        """Perform a GET request.
 
         Args:
             endpoint: The API endpoint.
@@ -30,11 +31,12 @@ class Resource:
 
         Returns:
             The HTTP response.
+
         """
         return self.client._request(method="GET", endpoint=endpoint, **kwargs)
 
     def _post(self, endpoint: str, **kwargs: Any) -> Response:
-        """Helper method to perform a POST request.
+        """Perform a POST request.
 
         Args:
             endpoint: The API endpoint.
@@ -42,11 +44,12 @@ class Resource:
 
         Returns:
             The HTTP response.
+
         """
         return self.client._request(method="POST", endpoint=endpoint, **kwargs)
 
     def _put(self, endpoint: str, **kwargs: Any) -> Response:
-        """Helper method to perform a PUT request.
+        """Perform a PUT request.
 
         Args:
             endpoint: The API endpoint.
@@ -54,11 +57,12 @@ class Resource:
 
         Returns:
             The HTTP response.
+
         """
         return self.client._request(method="PUT", endpoint=endpoint, **kwargs)
 
     def _delete(self, endpoint: str, **kwargs: Any) -> Response:
-        """Helper method to perform a DELETE request.
+        """Perform a DELETE request.
 
         Args:
             endpoint: The API endpoint.
@@ -66,11 +70,12 @@ class Resource:
 
         Returns:
             The HTTP response.
+
         """
         return self.client._request(method="DELETE", endpoint=endpoint, **kwargs)
 
     def _patch(self, endpoint: str, **kwargs: Any) -> Response:
-        """Helper method to perform a PATCH request.
+        """Perform a PATCH request.
 
         Args:
             endpoint: The API endpoint.
@@ -78,5 +83,6 @@ class Resource:
 
         Returns:
             The HTTP response.
+
         """
         return self.client._request(method="PATCH", endpoint=endpoint, **kwargs)
